import { Action, ActionArtifactBounds, CommonActionProps } from "./action";
import { Artifact } from "./artifact";
/**
 * Construction properties of the low level {@link BuildAction build action}.
 */
export interface BuildActionProps extends CommonActionProps {
    /**
     * The source to use as input for this build.
     */
    readonly inputArtifact: Artifact;
    /**
     * The service provider that the action calls. For example, a valid provider for Source actions is CodeBuild.
     */
    readonly provider: string;
    /**
     * The upper and lower bounds on the number of input and output artifacts for this Action.
     */
    readonly artifactBounds: ActionArtifactBounds;
    /**
     * The build Action owner (could be 'AWS', 'ThirdParty' or 'Custom').
     *
     * @default 'AWS'
     */
    readonly owner?: string;
    /**
     * The build Action version.
     *
     * @default '1'
     */
    readonly version?: string;
    /**
     * The name of the build's output artifact.
     */
    readonly outputArtifactName: string;
    /**
     * The action's configuration. These are key-value pairs that specify input values for an action.
     * For more information, see the AWS CodePipeline User Guide.
     *
     * http://docs.aws.amazon.com/codepipeline/latest/userguide/reference-pipeline-structure.html#action-requirements
     */
    readonly configuration?: any;
}
/**
 * Low level class for build actions.
 * It is recommended that concrete types are used instead,
 * such as {@link codebuild.PipelineBuildAction}.
 */
export declare abstract class BuildAction extends Action {
    readonly outputArtifact: Artifact;
    constructor(props: BuildActionProps);
}
